@@ -1,7 +1,7 @@
 
 /* png.c - location for general purpose libpng functions
  *
- * Last changed in libpng 1.2.19 August 18, 2007
+ * Last changed in libpng 1.2.19 August 19, 2007
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2007 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -13,7 +13,7 @@
 #include "png.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_0_27 Your_png_h_is_not_version_1_0_27;
+typedef version_1_0_28 Your_png_h_is_not_version_1_0_28;
 
 /* Version information for C files.  This had better match the version
  * string defined in png.h.  */
@@ -67,11 +67,6 @@ PNG_CONST int FARDATA png_pass_ystart[] = {0, 0, 4, 0, 2, 0, 1};
 /* offset to next interlace block in the y direction */
 PNG_CONST int FARDATA png_pass_yinc[] = {8, 8, 8, 4, 4, 2, 2};
 
-/* width of interlace block (used in assembler routines only) */
-#if defined(PNG_HAVE_MMX_COMBINE_ROW) || defined(PNG_OPTIMIZED_CODE_SUPPORTED)
-PNG_CONST int FARDATA png_pass_width[] = {8, 4, 4, 2, 2, 1, 1};
-#endif
-
 /* Height of interlace block.  This is not currently used - if you need
  * it, uncomment it here and in png.h
 PNG_CONST int FARDATA png_pass_height[] = {8, 8, 4, 4, 2, 2, 1};
@@ -698,7 +693,7 @@ png_charp PNGAPI
 png_get_copyright(png_structp png_ptr)
 {
    png_ptr = png_ptr;  /* silence compiler warning about unused png_ptr */
-   return ((png_charp) "\n libpng version 1.0.27 - August 18, 2007\n\
+   return ((png_charp) "\n libpng version 1.0.28 - September 8, 2007\n\
    Copyright (c) 1998-2007 Glenn Randers-Pehrson\n\
    Copyright (c) 1996-1997 Andreas Dilger\n\
    Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.\n");
@@ -734,52 +729,10 @@ png_get_header_version(png_structp png_ptr)
    /* Returns longer string containing both version and date */
    png_ptr = png_ptr;  /* silence compiler warning about unused png_ptr */
    return ((png_charp) PNG_HEADER_VERSION_STRING
-#ifdef PNG_READ_SUPPORTED
-#  ifdef PNG_USE_PNGGCCRD
-#    ifdef __x86_64__
-#      ifdef __PIC__
-   "     (PNGGCRD x86_64, PIC)\n"
-#      else
-#        ifdef PNG_THREAD_UNSAFE_OK
-   "     (PNGGCRD x86_64, Thread unsafe)\n"
-#        else
-   "     (PNGGCRD x86_64, Thread safe)\n"
-#        endif
-#      endif
-#    else
-#    ifdef PNG_THREAD_UNSAFE_OK
-   "     (PNGGCRD, Thread unsafe)\n"
-#      else
-   "     (PNGGCRD, Thread safe)\n"
-#      endif
-#    endif
-#  else
-#    ifdef PNG_USE_PNGVCRD
-#      ifdef __x86_64__
-   "     (x86_64 PNGVCRD)\n"
-#      else
-   "     (PNGVCRD)\n"
-#      endif
-#    else
-#      ifdef __x86_64__
-#        ifdef PNG_OPTIMIZED_CODE_SUPPORTED
-   "     (x86_64 OPTIMIZED)\n"
-#        else
-   "     (x86_64 NOT OPTIMIZED)\n"
-#        endif
-#      else
-#        ifdef PNG_OPTIMIZED_CODE_SUPPORTED
-   "     (OPTIMIZED)\n"
-#        else
-   "     (NOT OPTIMIZED)\n"
-#        endif
-#      endif
-#    endif
-#  endif
-#else
-   "     (NO READ SUPPORT)\n"
+#ifndef PNG_READ_SUPPORTED
+   "     (NO READ SUPPORT)"
 #endif
-   );
+   "\n");
 }
 
 #if defined(PNG_READ_SUPPORTED) || defined(PNG_WRITE_SUPPORTED)
@@ -820,63 +773,13 @@ png_access_version_number(void)
 
 #if defined(PNG_READ_SUPPORTED) && defined(PNG_ASSEMBLER_CODE_SUPPORTED)
 #if !defined(PNG_1_0_X)
-#if defined(PNG_MMX_CODE_SUPPORTED)
-/* this INTERNAL function was added to libpng 1.2.0 */
-void /* PRIVATE */
-png_init_mmx_flags (png_structp png_ptr)
-{
-    if(png_ptr == NULL) return;
-    png_ptr->mmx_rowbytes_threshold = 0;
-    png_ptr->mmx_bitdepth_threshold = 0;
-
-#  if (defined(PNG_USE_PNGVCRD) || defined(PNG_USE_PNGGCCRD))
-
-    png_ptr->asm_flags |= PNG_ASM_FLAG_MMX_SUPPORT_COMPILED;
-
-    if (png_mmx_support() > 0) {
-        png_ptr->asm_flags |= PNG_ASM_FLAG_MMX_SUPPORT_IN_CPU
-#    ifdef PNG_HAVE_MMX_COMBINE_ROW
-                              | PNG_ASM_FLAG_MMX_READ_COMBINE_ROW
-#    endif
-#    ifdef PNG_HAVE_MMX_READ_INTERLACE
-                              | PNG_ASM_FLAG_MMX_READ_INTERLACE
-#    endif
-#    ifndef PNG_HAVE_MMX_READ_FILTER_ROW
-                              ;
-#    else
-                              | PNG_ASM_FLAG_MMX_READ_FILTER_SUB
-                              | PNG_ASM_FLAG_MMX_READ_FILTER_UP
-                              | PNG_ASM_FLAG_MMX_READ_FILTER_AVG
-                              | PNG_ASM_FLAG_MMX_READ_FILTER_PAETH ;
-
-        png_ptr->mmx_rowbytes_threshold = PNG_MMX_ROWBYTES_THRESHOLD_DEFAULT;
-        png_ptr->mmx_bitdepth_threshold = PNG_MMX_BITDEPTH_THRESHOLD_DEFAULT;
-#    endif
-    } else {
-        png_ptr->asm_flags &= ~( PNG_ASM_FLAG_MMX_SUPPORT_IN_CPU
-                               | PNG_MMX_READ_FLAGS
-                               | PNG_MMX_WRITE_FLAGS );
-    }
-
-#  else /* !(PNGVCRD || PNGGCCRD) */
-
-    /* clear all MMX flags; no support is compiled in */
-    png_ptr->asm_flags &= ~( PNG_MMX_FLAGS );
-
-#  endif /* ?(PNGVCRD || PNGGCCRD) */
-}
-
-#endif /* !(PNG_MMX_CODE_SUPPORTED) */
-
 /* this function was added to libpng 1.2.0 */
-#if !defined(PNG_USE_PNGGCCRD) && \
-    !(defined(PNG_MMX_CODE_SUPPORTED) && defined(PNG_USE_PNGVCRD))
 int PNGAPI
 png_mmx_support(void)
 {
+   /* obsolete, to be removed from libpng-1.4.0 */
     return -1;
 }
-#endif
 #endif /* PNG_1_0_X */
 #endif /* PNG_READ_SUPPORTED && PNG_ASSEMBLER_CODE_SUPPORTED */
 
